==> nextcloud-23.0.8.tgz: nextcloud/apps/text/l10n/fi.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "Uusi tekstitiedosto",
    "The file was uploaded" : "Tiedosto lähetettiin",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Ladattu tiedosto on suurempi kuin php.ini-tiedostossa määritelty upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ladattu tiedosto on suurempi kuin HTML-lomakkeessa määritelty MAX_FILE_SIZE",
    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
    "No file was uploaded" : "Tiedostoa ei lähetetty",
    "Missing a temporary folder" : "Väliaikaiskansio puuttuu",
    "Could not write file to disk" : "Ei voitu kirjoittaa levylle",
    "A PHP extension stopped the file upload" : "PHP-laajennus pysäytti tiedoston lähetyksen",
    "No file uploaded or file size exceeds maximum of %s" : "Tiedostoa ei lähetetty tai sen koko ylitti maksimin %s",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "Tekstiasiakirja",
    "Readme" : "Lueminut",
    "Text" : "Teksti",
    "📝 Collaborative document editing" : "📝 Yhteistyöhön perustuvaa asiakirjojen muokkausta",
    "Use current version" : "Käytä nykyistä versiota",
    "Use the saved version" : "Käytä tallennettua versiota",
    "Document idle for {timeout} minutes, click to continue editing" : "Dokumentti on ollut käyttämättömänä {timeout} minuuttia, klikkaa jatkaaksesi muokkausta",
    "Reconnect" : "Yhdistä uudelleen",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Dokumenttia on muutettu editorin ulkopuolella. Muutoksia ei voida tallentaa.",
    "File could not be loaded. Please check your internet connection." : "Tiedostoa ei voitu ladata. Tarkista internetyhteytesi tila.",
    "This file is opened read-only as it is currently locked by {user}." : "Tämä tiedosto on avattu vain luku -tilassa, koska se on tällä hetkellä lukittu käyttäjän {user} toimesta.",
    "Enter your name so other people can see who is editing" : "Kirjoita nimesi, jotta muut näkevät kuka muokkaa asiakirjaa",
    "Edit guest name" : "Muokkaa vieraan nimeä",
    "Guest" : "Vieras",
    "Save guest name" : "Tallenna vieraan nimi",
    "Image file format not supported" : "Kuvan tiedostomuoto ei ole tuettu",
    "Insert an image" : "Lisää kuva",
    "guest" : "vieras",
    "Show author colors" : "Näytä tekijän värit",
    "Active people" : "Aktiiviset ihmiset",
    "Saving …" : "Tallennetaan...",
    "Saved" : "Tallennettu",
    "Last saved {lastSaved}" : "Viimeksi tallennettu {lastSaved}",
    "Unsaved changes" : "Tallentamattomia muutoksia",
    "No emoji found" : "Emojia ei löydy",
    "Formatting help" : "Muotoiluohje",
    "Speed up your writing with simple shortcuts." : "Nopeuta kirjoittamista pikanäppäimillä.",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "Kirjoita Markdown-syntaksia tai käytä alla olevia pikanäppäimiä.",
    "Just type the Markdown syntax from below." : "Kirjoita Markdown-syntaksia alapuolelta.",
    "Style" : "Tyyli",
    "Syntax" : "Syntaksi",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Bold" : "Lihavoitu",
    "Bold text" : "Lihavoitu teksti",
    "Italic" : "Kursivoitu",
    "Italicized text" : "Kursivoitu teksti",
    "Strikethrough" : "Yliviivattu",
    "Shift" : "Siirrä",
    "Underline" : "Alleviivattu",
    "Underlined text" : "Alleviivattu teksti",
    "Heading 1" : "Otsikko 1",
    "Heading level 1" : "Otsikkotaso 1",
    "Heading 6" : "Otsikko 6",
    "Heading level 6" : "Otsikkotaso 6",
    "Unordered list" : "Lista",
    "An item" : "Tietue",
    "Ordered list" : "Numeroitu lista",
    "First item" : "Ensimmäinen tietue",
    "Checklist" : "Tarkistuslista",
    "Blockquote" : "Lohkolainaus",
    "Quoted text" : "Lainattu teksti",
    "Code block" : "Koodilohko",
    "Some code" : "Koodia",
    "Upload from computer" : "Lähetä tietokoneelta",
    "Insert from Files" : "Syötä Tiedostot-sovelluksesta",
    "Update Link" : "Päivitä linkki",
    "Add Link" : "Lisää linkki",
    "Link file" : "Linkitä tiedosto",
    "Remove Link" : "Poista linkki",
    "Select file to link to" : "Valitse tiedosto johon linkitetään",
    "Failed to load" : "Lataaminen epäonnistui",
    "Unsupported image type" : "Ei-tuettu kuvatiedostomuoto",
    "Add row before" : "Lisää rivi ennen",
    "Add row after" : "Lisää rivi jälkeen",
    "Delete this row" : "Poista tämä rivi",
    "Add column before" : "Lisää sarake ennen",
    "Add column after" : "Lisää sarake jälkeen",
    "Delete this column" : "Poista tämä sarake",
    "Delete this table" : "Poista tämä taulu",
    "Show rich workspaces" : "Näytä rikastetut työtilat",
    "Add notes, lists or links …" : "Lisää muistiinpanoja, listoja tai linkkejä...",
    "Undo" : "Kumoa",
    "Redo" : "Tee uudelleen",
    "Headings" : "Otsikot",
    "Heading 2" : "Otsikko 2",
    "Heading 3" : "Otsikko 3",
    "Heading 4" : "Otsikko 4",
    "Heading 5" : "Otsikko 5",
    "Info" : "Tietoa",
    "Success" : "Onnistui",
    "Warning" : "Varoitus",
    "Table" : "Taulukko",
    "Insert emoji" : "Lisää emoji",
    "Insert image" : "Lisää kuva",
    "Command" : "Komento",
    "Control" : "Hallinta",
    "Edit" : "Muokkaa",
    "New text document" : "Uusi tekstiasiakirja",
    "Enter your name so other users can see who is editing" : "Kirjoita nimesi, jotta muut näkevät kuka muokkaa asiakirjaa",
    "Currently active users:" : "Aktiiviset käyttäjät nyt:",
    "_and %n other editor_::_and %n other editors_" : ["ja %n muu muokkaaja","ja %n muuta muokkaajaa"],
    "ToDo list" : "Tehtävälista",
    "Emoji picker" : "Emoji-valitsin"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.12p1.tgz: nextcloud/apps/text/l10n/fi.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "Uusi tekstitiedosto",
    "The file was uploaded" : "Tiedosto lähetettiin",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Ladattu tiedosto on suurempi kuin php.ini-tiedostossa määritelty upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ladattu tiedosto on suurempi kuin HTML-lomakkeessa määritelty MAX_FILE_SIZE",
    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
    "No file was uploaded" : "Tiedostoa ei lähetetty",
    "Missing a temporary folder" : "Väliaikaiskansio puuttuu",
    "Could not write file to disk" : "Ei voitu kirjoittaa levylle",
    "A PHP extension stopped the file upload" : "PHP-laajennus pysäytti tiedoston lähetyksen",
    "No file uploaded or file size exceeds maximum of %s" : "Tiedostoa ei lähetetty tai sen koko ylitti maksimin %s",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "Tekstiasiakirja",
    "{user} has mentioned you in the text document {node}" : "{user} mainitsi sinut tekstiasiakirjassa {node}",
    "Readme" : "Lueminut",
    "Text" : "Teksti",
    "📝 Collaborative document editing" : "📝 Yhteistyöhön perustuvaa asiakirjojen muokkausta",
    "Use current version" : "Käytä nykyistä versiota",
    "Use the saved version" : "Käytä tallennettua versiota",
    "Document idle for {timeout} minutes, click to continue editing" : "Dokumentti on ollut käyttämättömänä {timeout} minuuttia, klikkaa jatkaaksesi muokkausta",
    "Reconnect" : "Yhdistä uudelleen",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Dokumenttia on muutettu editorin ulkopuolella. Muutoksia ei voida tallentaa.",
    "File could not be loaded. Please check your internet connection." : "Tiedostoa ei voitu ladata. Tarkista internetyhteytesi tila.",
    "This file is opened read-only as it is currently locked by {user}." : "Tämä tiedosto on avattu vain luku -tilassa, koska se on tällä hetkellä lukittu käyttäjän {user} toimesta.",
    "Enter your name so other people can see who is editing" : "Kirjoita nimesi, jotta muut näkevät kuka muokkaa asiakirjaa",
    "Edit guest name" : "Muokkaa vieraan nimeä",
    "Guest" : "Vieras",
    "Save guest name" : "Tallenna vieraan nimi",
    "Insert an attachment" : "Lisää liite",
    "guest" : "vieras",
    "Show author colors" : "Näytä tekijän värit",
    "Author colors are only shown until everyone has closed the document." : "Tekijöiden värit näytetään siihen asti, kunnes kaikki ovat sulkeneet asiakirjan.",
    "Active people" : "Aktiiviset ihmiset",
    "Document save status" : "Asiakirjan tallennuksen tila",
    "Last saved" : "Viimeksi tallennettu",
    "Saving …" : "Tallennetaan...",
    "Saved" : "Tallennettu",
    "Last saved {lastSaved}" : "Viimeksi tallennettu {lastSaved}",
    "Unsaved changes" : "Tallentamattomia muutoksia",
    "No emoji found" : "Emojia ei löydy",
    "Formatting help" : "Muotoiluohje",
    "Speed up your writing with simple shortcuts." : "Nopeuta kirjoittamista pikanäppäimillä.",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "Kirjoita Markdown-syntaksia tai käytä alla olevia pikanäppäimiä.",
    "Just type the Markdown syntax from below." : "Kirjoita Markdown-syntaksia alapuolelta.",
    "Style" : "Tyyli",
    "Syntax" : "Syntaksi",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Bold" : "Lihavoitu",
    "Bold text" : "Lihavoitu teksti",
    "Italic" : "Kursivoitu",
    "Italicized text" : "Kursivoitu teksti",
    "Strikethrough" : "Yliviivattu",
    "Shift" : "Siirrä",
    "Underline" : "Alleviivattu",
    "Underlined text" : "Alleviivattu teksti",
    "Heading 1" : "Otsikko 1",
    "Heading level 1" : "Otsikkotaso 1",
    "Heading 6" : "Otsikko 6",
    "Heading level 6" : "Otsikkotaso 6",
    "Unordered list" : "Lista",
    "An item" : "Tietue",
    "Ordered list" : "Numeroitu lista",
    "First item" : "Ensimmäinen tietue",
    "Checklist" : "Tarkistuslista",
    "Blockquote" : "Lohkolainaus",
    "Quoted text" : "Lainattu teksti",
    "Code block" : "Koodilohko",
    "Some code" : "Koodia",
    "No user found" : "Käyttäjää ei löytynyt",
    "Upload from computer" : "Lähetä tietokoneelta",
    "Insert from Files" : "Syötä Tiedostot-sovelluksesta",
    "Remove link" : "Poista linkki",
    "Link to file or folder" : "Linkki tiedostoon tai kansioon",
    "Link to website" : "Linkki verkkosivulle",
    "Update link" : "Päivitä linkki",
    "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
    "_%n word_::_%n words_" : ["%n sana","%n sanaa"],
    "_%n char_::_%n chars_" : ["%n merkki","%n merkkiä"],
    "Formatting menu bar" : "Muotoiluvalikko",
    "Link to this section" : "Linkki tähän osioon",
    "Delete this attachment" : "Poista tämä liite",
    "Delete this image" : "Poista tämä kuva",
    "Failed to load" : "Lataaminen epäonnistui",
    "Unsupported image type" : "Ei-tuettu kuvatiedostomuoto",
    "Add row before" : "Lisää rivi ennen",
    "Add row after" : "Lisää rivi jälkeen",
    "Delete this row" : "Poista tämä rivi",
    "Add column before" : "Lisää sarake ennen",
    "Add column after" : "Lisää sarake jälkeen",
    "Delete this column" : "Poista tämä sarake",
    "Delete this table" : "Poista tämä taulu",
    "Show rich workspaces" : "Näytä rikastetut työtilat",
    "Add notes, lists or links …" : "Lisää muistiinpanoja, listoja tai linkkejä...",
    "Undo" : "Kumoa",
    "Redo" : "Tee uudelleen",
    "Headings" : "Otsikot",
    "Heading 2" : "Otsikko 2",
    "Heading 3" : "Otsikko 3",
    "Heading 4" : "Otsikko 4",
    "Heading 5" : "Otsikko 5",
    "To-Do list" : "Tehtävälista",
    "Info" : "Tietoa",
    "Success" : "Onnistui",
    "Warning" : "Varoitus",
    "Table" : "Taulukko",
    "Insert emoji" : "Lisää emoji",
    "Insert attachment" : "Lisää liite",
    "Command" : "Komento",
    "Control" : "Hallinta",
    "Edit" : "Muokkaa",
    "Enter your name so other users can see who is editing" : "Kirjoita nimesi, jotta muut näkevät kuka muokkaa asiakirjaa",
    "Insert image" : "Lisää kuva",
    "Insert an image" : "Lisää kuva",
    "Update Link" : "Päivitä linkki",
    "Add Link" : "Lisää linkki",
    "Link file" : "Linkitä tiedosto",
    "Select file to link to" : "Valitse tiedosto johon linkitetään",
    "Currently active users:" : "Aktiiviset käyttäjät nyt:",
    "_and %n other editor_::_and %n other editors_" : ["ja %n muu muokkaaja","ja %n muuta muokkaajaa"],
    "ToDo list" : "Tehtävälista",
    "Emoji picker" : "Emoji-valitsin",
    "Image file format not supported" : "Kuvan tiedostomuoto ei ole tuettu",
    "Remove Link" : "Poista linkki"
},
"nplurals=2; plural=(n != 1);");
